@@ -6,7 +6,7 @@ from .LR import *
 from .KNN import *
 import matplotlib.pyplot as plt
 from sklearn.base import BaseEstimator, ClassifierMixin
-from sklearn.model_selection import train_test_split
+from sklearn.model_selection import train_test_split, GridSearchCV
 from sklearn.ensemble import StackingClassifier
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.svm import SVC
@@ -566,9 +566,9 @@ class FSSE(BaseEstimator, ClassifierMixin):
         '''
 
         # print(fsse.meta_learner.l1_ratio_)
-        N = np.count_nonzero(fsse.meta_learner.coef_[0])
+        N = np.count_nonzero(self.meta_learner.coef_[0])
         
-        biggest_fsse_gs = (np.argsort(np.abs(fsse.meta_learner.coef_[0]))[-N:])[::-1] # take last N item indices and reverse (ord desc)
+        biggest_fsse_gs = (np.argsort(np.abs(self.meta_learner.coef_[0]))[-N:])[::-1] # take last N item indices and reverse (ord desc)
         biggest_fsse_fs = []
 
         for idx in biggest_fsse_gs:
@@ -585,7 +585,7 @@ class FSSE(BaseEstimator, ClassifierMixin):
 
         return biggest_fsse_fs, fs_importance
 
-def fsse_homo_stacking(create_base_estimator_cv, split_range = range(1, 20), repeat = 3, summary = 'median'):
+def fsse_homo_stacking(X, y, create_base_estimator_cv, split_range = range(1, 20), repeat = 3, summary = 'median'):
 
     accs = []
     r = split_range
@@ -598,8 +598,8 @@ def fsse_homo_stacking(create_base_estimator_cv, split_range = range(1, 20), rep
             accs_repeat = []
 
             fsse = FSSE(create_base_estimator_cv, feature_split = split)
-            fsse.fit(X_scaled, y)
-            accs_repeat.append(fsse.evaluate(X_scaled, y))
+            fsse.fit(X, y)
+            accs_repeat.append(fsse.evaluate(X, y))
 
         if summary == 'median':
             accs.append( np.median(accs_repeat) )
